@@ -154,6 +154,17 @@ def set_jabberid(sender, instance, **kwargs):
         instance.jabberRoom = True
 
 
+@receiver(post_save, sender=Project)
+def set_creator_as_member(instance, created, **kwargs):
+    if created:
+        request_user = getattr(instance, MODEL_MODIFICATION_USER_FIELD, None)
+        if request_user:
+            try:
+                Member.objects.create(user=request_user, project=instance, is_admin=True)
+            except Exception as e:
+                logger.error('Unable to set current user as member of the created project ' + str(e))
+
+
 @receiver(post_save, sender=Project)
 def set_captain_as_member(instance, created, **kwargs):
     if instance.captain is not None:
